WlanFullmacImplIfcDisassocIndRequest

Struct WlanFullmacImplIfcDisassocIndRequest 

pub struct WlanFullmacImplIfcDisassocIndRequest {
    pub peer_sta_address: Option<[u8; 6]>,
    pub reason_code: Option<ReasonCode>,
    pub locally_initiated: Option<bool>,
    /* private fields */
}

Fields

peer_sta_address: Option<[u8; 6]>

Address of the peer that was disassociated. Required.

reason_code: Option<ReasonCode>

Reason for the disassociation. Required.

locally_initiated: Option<bool>

Whether the disassociation was initiated from the device. Required. locally_initiated is true if disassociation was initiated from the device (e.g. firmware or vendor driver started the disassociation); false if the disassociation was initiated externally (e.g. due to receipt of a disassociate frame from an AP).