WlanFullmacImplIfcRoamResultIndRequest

Struct WlanFullmacImplIfcRoamResultIndRequest 

pub struct WlanFullmacImplIfcRoamResultIndRequest {
    pub selected_bssid: Option<[u8; 6]>,
    pub status_code: Option<StatusCode>,
    pub original_association_maintained: Option<bool>,
    pub target_bss_authenticated: Option<bool>,
    pub association_id: Option<u16>,
    pub association_ies: Option<Vec<u8>>,
    /* private fields */
}

Fields

selected_bssid: Option<[u8; 6]>

BSSID of the target BSS. Required.

status_code: Option<StatusCode>

Result of the roam attempt. Required.

original_association_maintained: Option<bool>

Whether the original BSS association has been maintained through the roam attempt. Required. A successful roam always incurs disassociation from the original BSS, so if status_code is success then this field must be set to false; a roam failure typically incurs disassociation from the original BSS, but may not in some cases (e.g. in some Fast BSS Transition scenarios).

target_bss_authenticated: Option<bool>

Whether the client is authenticated with the target BSS. If status_code is success, then this field must be set to true; if the roam attempt failed, this field may be true or false. This allows higher layers to decide how to clean up connection state after a failed roam attempt.

association_id: Option<u16>

Association ID for this association with the AP. Required if status_code is success.

association_ies: Option<Vec<u8>>

IEs for this association with the AP. Required if status_code is success.