pub struct WlanFullmacImplQueryRssiMonitorSupportResponse {
pub resp: Option<RssiMonitorSupport>,
/* private fields */
}Fields
resp: Option<RssiMonitorSupport>Trait Implementations
Sourceimpl Clone for WlanFullmacImplQueryRssiMonitorSupportResponse
impl Clone for WlanFullmacImplQueryRssiMonitorSupportResponse
Sourcefn clone(&self) -> WlanFullmacImplQueryRssiMonitorSupportResponse
fn clone(&self) -> WlanFullmacImplQueryRssiMonitorSupportResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<WlanFullmacImplQueryRssiMonitorSupportResponse, D> for WlanFullmacImplQueryRssiMonitorSupportResponsewhere
D: ResourceDialect,
impl<D> Decode<WlanFullmacImplQueryRssiMonitorSupportResponse, D> for WlanFullmacImplQueryRssiMonitorSupportResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> WlanFullmacImplQueryRssiMonitorSupportResponse
fn new_empty() -> WlanFullmacImplQueryRssiMonitorSupportResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for WlanFullmacImplQueryRssiMonitorSupportResponse
impl Default for WlanFullmacImplQueryRssiMonitorSupportResponse
Sourcefn default() -> WlanFullmacImplQueryRssiMonitorSupportResponse
fn default() -> WlanFullmacImplQueryRssiMonitorSupportResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<WlanFullmacImplQueryRssiMonitorSupportResponse, D> for &WlanFullmacImplQueryRssiMonitorSupportResponsewhere
D: ResourceDialect,
impl<D> Encode<WlanFullmacImplQueryRssiMonitorSupportResponse, D> for &WlanFullmacImplQueryRssiMonitorSupportResponsewhere
D: ResourceDialect,
impl Persistable for WlanFullmacImplQueryRssiMonitorSupportResponse
impl StructuralPartialEq for WlanFullmacImplQueryRssiMonitorSupportResponse
Sourceimpl TypeMarker for WlanFullmacImplQueryRssiMonitorSupportResponse
impl TypeMarker for WlanFullmacImplQueryRssiMonitorSupportResponse
Sourcetype Owned = WlanFullmacImplQueryRssiMonitorSupportResponse
type Owned = WlanFullmacImplQueryRssiMonitorSupportResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for WlanFullmacImplQueryRssiMonitorSupportResponse
impl ValueTypeMarker for WlanFullmacImplQueryRssiMonitorSupportResponse
Sourcetype Borrowed<'a> = &'a WlanFullmacImplQueryRssiMonitorSupportResponse
type Borrowed<'a> = &'a WlanFullmacImplQueryRssiMonitorSupportResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<WlanFullmacImplQueryRssiMonitorSupportResponse as TypeMarker>::Owned,
) -> <WlanFullmacImplQueryRssiMonitorSupportResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<WlanFullmacImplQueryRssiMonitorSupportResponse as TypeMarker>::Owned, ) -> <WlanFullmacImplQueryRssiMonitorSupportResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for WlanFullmacImplQueryRssiMonitorSupportResponse
impl RefUnwindSafe for WlanFullmacImplQueryRssiMonitorSupportResponse
impl Send for WlanFullmacImplQueryRssiMonitorSupportResponse
impl Sync for WlanFullmacImplQueryRssiMonitorSupportResponse
impl Unpin for WlanFullmacImplQueryRssiMonitorSupportResponse
impl UnsafeUnpin for WlanFullmacImplQueryRssiMonitorSupportResponse
impl UnwindSafe for WlanFullmacImplQueryRssiMonitorSupportResponse