WlanFullmacImplStartScanRequest

Struct WlanFullmacImplStartScanRequest 

pub struct WlanFullmacImplStartScanRequest {
    pub txn_id: Option<u64>,
    pub scan_type: Option<WlanScanType>,
    pub channels: Option<Vec<ChannelNumber>>,
    pub ssids: Option<Vec<Vec<u8>>>,
    pub min_channel_time: Option<u32>,
    pub max_channel_time: Option<u32>,
    /* private fields */
}

Fields

txn_id: Option<u64>

Unique transaction id (will be indicated in corresponding scan results).

scan_type: Option<WlanScanType>channels: Option<Vec<ChannelNumber>>

List of channels to scan on. An empty list of channels will cause a scan request to immediately return a OnScanEnd with code INVALID_ARGS.

Invalid channel numbers will be silently ignored. The validity of a channel number depends on the current regulatory region, and a FullMAC driver cannot always determine the region setting. This is especially the case when firmware changes the region setting dynamically.

ssids: Option<Vec<Vec<u8>>>

List of SSIDs to scan for. An empty list of ssids is the same as specifying a list containing only the wildcard SSID.

There is no limit on the number of SSIDs specified. A large number of SSIDs may result in extended scan times because of hardware limitations on the number of SSIDs permitted per scan request and the technical limitation in IEEE 802.11-2016 that limits the number of SSIDs in a single Probe Request frame to ieee80211.SSID_LIST_MAX SSIDs.

min_channel_time: Option<u32>

Minimum amount of time in msecs spent on a channel during scan.

max_channel_time: Option<u32>

Maximum amount of time in msecs spent on a channel during scan.